"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const dayjs = require("dayjs");
const ProgressBar = require("progress");
const yargs = require("yargs");
const utils_1 = require("../utils");
exports.command = "fake";
exports.desc = `-d -s -f : generate fake EXIF  and file atimestamps on a linear distribution between start and finish times`;
exports.fake = (directory, startString, finishString) => __awaiter(this, void 0, void 0, function* () {
    // Initialize filesystem
    const files = yield utils_1.lsJpeg(directory);
    // Calculate date range and step size
    const start = dayjs(startString);
    const finish = dayjs(finishString);
    const difference = finish.diff(start);
    const increment = difference / files.length;
    // Debug Input Parameters
    utils_1.logger.debug(`Directory: ${directory}`);
    utils_1.logger.debug(`Start Time: ${start.format()}`);
    utils_1.logger.debug(`Finish Time: ${finish.format()}`);
    utils_1.logger.debug(`Increment (ms): ${increment}`);
    utils_1.logger.debug(`Files: ${utils_1.lsJpeg(directory)}`);
    const env = utils_1.execute("printenv env");
    // Loop over files and update Exif and file timestamp to new time
    const bar = new ProgressBar("fake [:bar]", {
        complete: "=",
        incomplete: " ",
        width: 70,
        total: files.length
    });
    let path = "";
    let timestamp = 0;
    let abandoned = [];
    for (let i = 0; i < files.length; i++) {
        bar.tick(1);
        path = `${directory}/${files[i]}`;
        timestamp = start + i * increment;
        try {
            let oldFileDateName;
            if (env && env.toString().startsWith("TEST")) {
                oldFileDateName = utils_1.jhead(utils_1.osAgnosticFileDateTime(path));
            }
            else {
                oldFileDateName = utils_1.jhead(utils_1.dumpFileDateName(path));
            }
            const setResult = yield utils_1.jhead(utils_1.setExifTime(timestamp, path));
            if (setResult.includes("contains no Exif timestamp to change")) {
                yield utils_1.jhead(utils_1.makeExifSection(path));
                yield utils_1.jhead(utils_1.setExifTime(timestamp, path));
            }
            utils_1.jhead(utils_1.setFileTimeToExifTime(path));
            let newExifTimeFileDateName;
            if (env && env.toString().startsWith("TEST")) {
                newExifTimeFileDateName = utils_1.jhead(utils_1.osAgnosticFileDateTime(path));
                utils_1.logger.debug(`${oldFileDateName}=> \n${newExifTimeFileDateName}`);
            }
            else {
                // TODO add option to log this if in verbose mode and hide the progress bar
                newExifTimeFileDateName = utils_1.jhead(utils_1.dumpExifTimeFileDateName(path));
            }
        }
        catch (e) {
            abandoned.push({ path });
            utils_1.logger.error(`Fatal error when running fake command on ${path} with timestamp ${timestamp}.`, e);
        }
    }
    utils_1.logger.debug("Done. 🍺");
});
exports.handler = () => __awaiter(this, void 0, void 0, function* () {
    try {
        var argv = yargs
            .option("d", {
            alias: "directory",
            demandOption: true,
            describe: "start time",
            type: "string"
        })
            .option("s", {
            alias: "start",
            demandOption: true,
            describe: "start time",
            type: "string"
        })
            .option("f", {
            alias: "finish",
            demandOption: true,
            describe: "finish time",
            type: "string"
        }).argv;
        exports.fake(argv.d, argv.s, argv.f);
    }
    catch (e) {
        utils_1.logger.error("[ERROR]", e);
    }
});
//# sourceMappingURL=fake.js.map