"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const compareImages = require("resemblejs/compareImages");
const fs = require("fs-extra");
const ProgressBar = require("progress");
const yargs = require("yargs");
const utils_1 = require("../utils");
exports.command = "matchmv";
exports.desc = `-d -m -r : renamed with prefix matched files in match directory that also are found in source directory`;
exports.imgDiff = (img1path, img2path, diffPath = null) => __awaiter(this, void 0, void 0, function* () {
    const data = yield compareImages(yield fs.readFile(img1path), yield fs.readFile(img2path));
    if (diffPath) {
        yield fs.writeFile(diffPath, data.getBuffer());
    }
    const { analysisTime, misMatchPercentage } = data;
    return { analysisTime, misMatchPercentage };
});
exports.batchImgDiff = (directory, matchDirectory) => __awaiter(this, void 0, void 0, function* () {
    // Initialize filesystem
    const srcFiles = yield utils_1.lsJpeg(directory);
    const matchFiles = yield utils_1.lsJpeg(matchDirectory);
    // Files
    utils_1.logger.debug(`srcFiles: ${srcFiles}`);
    utils_1.logger.debug(`matchFiles: ${matchFiles}`);
    // Loop over files, adding to map and renaming with prefix if file matches
    let results = [];
    let sfMatched = {};
    let mfMatched = {};
    let srcPath = "";
    let matchPath = "";
    const bar = new ProgressBar("matchmv [:bar]", {
        complete: "=",
        incomplete: " ",
        width: 70,
        total: matchFiles.length * srcFiles.length
    });
    for (const mf of matchFiles) {
        bar.tick(1);
        if (mfMatched[mf]) {
            continue;
        }
        matchPath = `${matchDirectory}/${mf}`;
        for (const sf of srcFiles) {
            bar.tick(1);
            if (sfMatched[sf]) {
                continue;
            }
            srcPath = `${directory}/${sf}`;
            try {
                let diffResult = yield exports.imgDiff(matchPath, srcPath);
                if (diffResult.misMatchPercentage < 1.0) {
                    sfMatched[sf] = mf;
                    mfMatched[mf] = sf;
                    results.push({ mf, sf, diffResult });
                }
            }
            catch (e) {
                utils_1.logger.error(`[ERROR] Processing image diff between ${matchPath} and ${srcPath}. ${e}`);
            }
        }
    }
    return results;
});
exports.matchmv = (directory, matchDirectory, renamePrefix) => __awaiter(this, void 0, void 0, function* () {
    // Debug Input Parameters
    utils_1.logger.debug(`Source Directory: ${directory}`);
    utils_1.logger.debug(`Match Directory: ${matchDirectory}`);
    utils_1.logger.debug(`Rename Prefix: ${renamePrefix}`);
    const results = yield exports.batchImgDiff(directory, matchDirectory);
    for (const res of results) {
        yield fs.move(`${matchDirectory}/${res.mf}`, `${matchDirectory}/${renamePrefix}${res.mf}`);
    }
    // Results
    const matchFiles = yield utils_1.lsJpeg(matchDirectory);
    utils_1.logger.debug(`matchFiles: ${matchFiles}`);
    utils_1.logger.debug("Done. 🍺");
});
exports.handler = () => __awaiter(this, void 0, void 0, function* () {
    try {
        var argv = yargs
            .option("d", {
            alias: "directory",
            describe: "source directory",
            type: "string"
        })
            .option("m", {
            alias: "matchDirectory",
            describe: "match directory",
            type: "string"
        })
            .option("r", {
            alias: "renamePrefix",
            describe: "prefix that matched files are renamed with",
            type: "string"
        }).argv;
        exports.matchmv(argv.d, argv.m, argv.r);
    }
    catch (e) {
        utils_1.logger.error("[ERROR]", e);
    }
});
//# sourceMappingURL=matchmv.js.map