"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const dayjs = require("dayjs");
const utils_1 = require("../utils");
exports.installJheadWarning = () => {
    utils_1.logger.error("No local jhead installation found. Try installing with the commands below.\n\tLinux: sudo apt-get update && sudo apt-get install -y jhead\n\tMac: brew install jhead");
};
exports.jhead = (cmd) => {
    try {
        const result = child_process_1.execSync(cmd, { stdio: "pipe", encoding: "utf-8" });
        return result;
    }
    catch (e) {
        exports.installJheadWarning();
    }
};
exports.dumpExifHeader = (path) => `jhead -exifmap ${path}`;
exports.dumpExifMap = (path) => `${exports.dumpExifHeader(path)} | grep Map`;
exports.osAgnosticFileDateTime = (path) => `${exports.dumpExifHeader(path)} | grep -v Map`;
exports.dumpFileDateName = (path) => `${exports.dumpExifHeader(path)} | sort | tail -n +3 | head -2`;
exports.dumpExifTimeFileDateName = (path) => `${exports.dumpExifHeader(path)} | sort | tail -n +3 | head -3`;
exports.makeExifSection = (path, outputVerbosityControl = "-q") => `jhead ${outputVerbosityControl} -mkexif ${path}`;
exports.setExifTime = (newTime, path, outputVerbosityControl = "-q") => `jhead ${outputVerbosityControl} -ts${dayjs(newTime).format(utils_1.jheadTimeFormat)} ${path}`;
exports.setFileTimeToExifTime = (path, outputVerbosityControl = "-q") => `jhead ${outputVerbosityControl} -ft ${path}`;
//# sourceMappingURL=jhead.js.map